@@ -168,6 +168,7 @@ mediaShow.fullscreen= function (slideshowIndex)
        slideshow.oldParentIndex = $(slideshow.obj).parent().children().index($(slideshow.obj))
        $('body').append(slideshow.obj);
        $(slideshow.obj).addClass("fullscreen")
+       $('body').addClass("fullscreen")
        if (!$.browser.msie)
        {
             mediaShow.reAlign()
@@ -191,6 +192,7 @@ mediaShow.fullscreen= function (slideshowIndex)
             slideshow.oldParentIndex = undefined;
         }
        $(slideshow.obj).removeClass("fullscreen")
+       $('body').removeClass("fullscreen")
         if (!$.browser.msie)
        {
             mediaShow.reAlign()
